<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 * @return array An array of default values
 */

function pet_business_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$pet_business_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#2a2e43',
		'header_tagline_color'			=> '#82868b',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		// typography Options
		'theme_typography' 				=> '',
		'body_theme_typography' 		=> '',
		
		// nav btn
		'nav_btn'         				=> true,
		'nav_btn_txt'           		=> esc_html__( 'Adapt pet', 'pet-business-pro' ),
		'nav_btn_url'           		=> '#',

		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'menu_style'					=> 'classic-menu',
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'pet-business-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'pet-business-pro' ), '[the-year]', '[site-link]' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'pet-business-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'footer_social_visible'        	=> false,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Slider,Service,About,Project,Testimonial,Product,Pricing,Call to Action,Team,Counter,Blog,Contact,Client',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'pet-business-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'archive_col'					=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Topbar
		'topbar_section_enable'			=> false,
		'phone_no'						=> esc_html__( '123 456 789', 'pet-business-pro' ),
		'email_address'					=> esc_html__( 'info@petmedical.com', 'pet-business-pro' ),
		
		//homepage layot
		'home_layout'					=> 'default-design',

		// slider
		'slider_section_enable'		=> true,
		'slider_content_type'		=> 'category',
		'slider_count'				=> 4,
		'slider_blog_button'		=> esc_html__( 'Read More', 'pet-business-pro' ),

		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'					=> 4,
		'team_title'					=> esc_html__( 'Our Team', 'pet-business-pro' ),
		'team_sub_title'				=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'custom',
		'about_title'					=> esc_html__( 'About Us', 'pet-business-pro' ),
		'about_description'				=> esc_html__( 'There are many examples of organisational systems in nature. From the self-organisation of molecules to form crystals, or entrancing displays of a murmuration of starlings, to the stigmergic communications of ants and the growth of a whole animal from just two starting cells...', 'pet-business-pro' ),
		'about_btn_title'				=> esc_html__( 'Learn more', 'pet-business-pro' ),
		'video_section_enable'			=> true,
		'ads_image'			=> '',

		// service
		'service_section_enable'			=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_title'					=> esc_html__( 'Pet Services', 'pet-business-pro' ),
		'service_sub_title'					=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),
		'service_button'					=> esc_html__( 'Learn More', 'pet-business-pro' ),

		// project
		'project_section_enable'			=> true,
		'project_content_type'			=> 'category',
		'project_count'					=> 3,
		'project_title'					=> esc_html__( 'Latest Projects', 'pet-business-pro' ),
		'project_sub_title'				=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),

		// product
		'product_section_enable'			=> true,
		'product_content_type'			=> 'category',
		'product_count'					=> 4 ,
		'product_title'					=> esc_html__( 'Our Cute Puppies', 'pet-business-pro' ),
		'product_sub_title'				=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),

		// pricing
		'pricing_section_enable'			=> true,
		'pricing_content_type'			=> 'category',
		'pricing_count'					=> 3,
		'pricing_title'					=> esc_html__( 'Pet Packages', 'pet-business-pro' ),
		'pricing_sub_title'				=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'post',
		'testimonial_title'				=> esc_html__( 'Our Pet Lovers', 'pet-business-pro' ),
		'testimonial_count' 		=> 3,	

		// counter
		'counter_section_enable'			=> true,
		'counter_count'					=> 4,

		// call to action
		'cta_section_enable_1'			=> true,
		'cta_content_type_1'				=> 'custom',
		'cta_title_1'						=> esc_html__( 'Hi! My name is Tommy', 'pet-business-pro' ),
		'cta_description_1'				=> esc_html__( 'There are many examples of organisational systems in nature. From the self-organisation of molecules to form crystals, or entrancing displays of a murmuration of starlings, to the stigmergic communications of ants and the growth of a whole animal from just two starting cells.', 'pet-business-pro' ),
		'cta_btn_title_1'					=> esc_html__( 'Adopt Tommy', 'pet-business-pro' ),

		'cta_section_enable_2'			=> true,
		'cta_content_type_2'				=> 'custom',
		'cta_title_2'						=> esc_html__( 'I am always your friend', 'pet-business-pro' ),
		'cta_description_2'				=> esc_html__( 'There are many examples of organisational systems in nature. From the self-organisation of molecules to form crystals, or entrancing displays of a murmuration of starlings, to the stigmergic communications of ants and the growth of a whole animal from just two starting cells.', 'pet-business-pro' ),
		'cta_btn_title_2'					=> esc_html__( 'Call To Action', 'pet-business-pro' ),

		// contact
		'contact_section_enable'			=> true,
		'contact_content_type'				=> 'page',
		'contact_title'						=> esc_html__( 'Choose me for the sake of beautiful web design', 'pet-business-pro' ),
		'contact_description'				=> esc_html__( 'There is evidence that perceptions of beauty are evolutionary determined, that things, aspects of people and landscapes considered beautiful are typically found in situations likely to give enhanced survival of the perceiving human\'s genes...', 'pet-business-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'From our Blog', 'pet-business-pro' ),
		'blog_subtitle'				=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),

		// must
		'must_section_enable'			=> true,
		'must_content_type'				=> 'category',
		'must_count'					=> 4,
		'must_column'					=> 'col-4',
		'must_title'					=> esc_html__( 'You Must Read', 'pet-business-pro' ),

		// most
		'most_section_enable'			=> true,
		'most_content_type'				=> 'category',
		'most_count'					=> 4,
		'most_title'					=> esc_html__( 'Popular Posts', 'pet-business-pro' ),

		// counter
		'client_title'					=> esc_html__( 'Our Main Clients', 'pet-business-pro' ),
		'client_subtitle'					=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),
		'client_section_enable'			=> true,
		'client_count'					=> 5,

		//popular post
		'popular_post_section_enable'			=> true,
		'popular_post_title'					=> esc_html__( 'Popular Posts', 'pet-business-pro' ),
		'popular_post_description'				=> esc_html__( 'A cultural icon is a person or artifact that is recognized by members of a culture or sub-culture as representing some aspect of cultural identity.', 'pet-business-pro' ),
		'popular_post_button'					=> esc_html__( 'Read More', 'pet-business-pro' ),
		'popular_post_count'					=> 4,
		'popular_post_content_type'				=> 'category',

		// Reason
		'reason_section_enable'			=> true,
		'reason_content_type'			=> 'page',
		'reason_title'					=> esc_html__( 'Analysis and Consulting', 'pet-business-pro' ),
		'reason_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'pet-business-pro' ),
		

	);

	$output = apply_filters( 'pet_business_pro_default_theme_options', $pet_business_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}