<?php
/**
 * Client Section options
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */

// Add Client section
$wp_customize->add_section( 'pet_business_pro_client_section', array(
	'title'             => esc_html__( 'Client','pet-business-pro' ),
	'description'       => esc_html__( 'Client Section options.', 'pet-business-pro' ),
	'panel'             => 'pet_business_pro_front_page_panel',
) );

// Client content enable control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[client_section_enable]', array(
	'default'			=> 	$options['client_section_enable'],
	'sanitize_callback' => 'pet_business_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pet_Business_Pro_Switch_Control( $wp_customize, 'pet_business_pro_theme_options[client_section_enable]', array(
	'label'             => esc_html__( 'Client Section Enable', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_client_section',
	'on_off_label' 		=> pet_business_pro_switch_options(),
) ) );

// blog title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[client_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['client_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[client_title]', array(
	'label'           	=> esc_html__( 'Title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_client_section',
	'active_callback' 	=> 'pet_business_pro_is_client_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[client_title]', array(
		'selector'            => '#partners-logo .section-header h2.section-title',
		'settings'            => 'pet_business_pro_theme_options[client_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_client_title_partial',
    ) );
}

// blog btn title setting and control
$wp_customize->add_setting( 'pet_business_pro_theme_options[client_subtitle]', array(
	'sanitize_callback' => 'sanitize_textarea_field',
	'default'			=> $options['client_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[client_subtitle]', array(
	'label'           	=> esc_html__( 'Sub title', 'pet-business-pro' ),
	'section'        	=> 'pet_business_pro_client_section',
	'active_callback' 	=> 'pet_business_pro_is_client_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pet_business_pro_theme_options[client_subtitle]', array(
		'selector'            => '#partners-logo .section-subtitle',
		'settings'            => 'pet_business_pro_theme_options[client_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pet_business_pro_client_subtitle_partial',
    ) );
}

// client number control and setting
$wp_customize->add_setting( 'pet_business_pro_theme_options[client_count]', array(
	'default'          	=> $options['client_count'],
	'sanitize_callback' => 'pet_business_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'pet_business_pro_theme_options[client_count]', array(
	'label'             => esc_html__( 'Number of Client', 'pet-business-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'pet-business-pro' ),
	'section'           => 'pet_business_pro_client_section',
	'active_callback'   => 'pet_business_pro_is_client_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );


for ( $i = 1; $i <= $options['client_count']; $i++ ) :
	// client number control and setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[client_image_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pet_business_pro_theme_options[client_image_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Image %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_client_section',
		'active_callback'   => 'pet_business_pro_is_client_section_enable',
	) ) );

	// client custom date
	$wp_customize->add_setting( 'pet_business_pro_theme_options[client_url_' . $i . ']', array(
		'default'			=> 	'#',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[client_url_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Link %d', 'pet-business-pro' ), $i ),
		'section'           => 'pet_business_pro_client_section',
		'active_callback'	=> 'pet_business_pro_is_client_section_enable',
	) );

	// client custom button
	$wp_customize->add_setting( 'pet_business_pro_theme_options[client_new_tab_' . $i . ']', array(
		'default'			=> 	false,
		'sanitize_callback' => 'pet_business_pro_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'pet_business_pro_theme_options[client_new_tab_' . $i . ']', array(
		'label'             => esc_html__( 'Open in new tab', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_client_section',
		'active_callback'	=> 'pet_business_pro_is_client_section_enable',
		'type'				=> 'checkbox'
	) );

	// Separator setting
	$wp_customize->add_setting( 'pet_business_pro_theme_options[client_separator_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new Pet_Business_Pro_Note_Control( $wp_customize, 'pet_business_pro_theme_options[client_separator_' . $i . ']', array(
		'label'             => __( '<hr style="width: 100%; border: 1px #bcb1b1 solid;"/>', 'pet-business-pro' ),
		'section'           => 'pet_business_pro_client_section',
		'active_callback'	=> 'pet_business_pro_is_client_section_enable',
		'type'				=> 'custom-html',
	) ) );
endfor;