<?php
/**
 * most section
 *
 * This is the template for the content of most section
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */
if ( ! function_exists( 'pet_business_pro_add_most_section' ) ) :
    /**
    * Add most section
    *
    *@since Pet Business Pro 1.0.0
    */
    function pet_business_pro_add_most_section() {
    	$options = pet_business_pro_get_theme_options();
        // Check if most is enabled on frontpage
        $most_enable = apply_filters( 'pet_business_pro_section_status', true, 'most_section_enable' );

        if ( true !== $most_enable ) {
            return false;
        }
        // Get most section details
        $section_details = array();
        $section_details = apply_filters( 'pet_business_pro_filter_most_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render most section now.
        pet_business_pro_render_most_section( $section_details );
    }
endif;

if ( ! function_exists( 'pet_business_pro_get_most_section_details' ) ) :
    /**
    * most section details.
    *
    * @since Pet Business Pro 1.0.0
    * @param array $input most section details.
    */
    function pet_business_pro_get_most_section_details( $input ) {
        $options = pet_business_pro_get_theme_options();

        // Content type.
        $most_content_type  = $options['most_content_type'];
        $most_count = ! empty( $options['most_count'] ) ? $options['most_count'] : 3;
        
        $content = array();
        switch ( $most_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $most_count; $i++ ) {
                    if ( ! empty( $options['most_content_page_' . $i] ) )
                        $page_ids[] = $options['most_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $most_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $most_count; $i++ ) {
                    if ( ! empty( $options['most_content_post_' . $i] ) )
                        $post_ids[] = $options['most_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $most_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['most_content_category'] ) ? $options['most_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $most_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['most_category_exclude'] ) ? $options['most_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $most_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['author_id'] = get_the_author_meta( 'ID' );
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = pet_business_pro_trim_content( 15 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// most section content details.
add_filter( 'pet_business_pro_filter_most_section_details', 'pet_business_pro_get_most_section_details' );


if ( ! function_exists( 'pet_business_pro_render_most_section' ) ) :
  /**
   * Start most section
   *
   * @return string most content
   * @since Pet Business Pro 1.0.0
   *
   */
   function pet_business_pro_render_most_section( $content_details = array() ) {
        $options = pet_business_pro_get_theme_options();
        $most_content_type  = $options['most_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="most-viewed-posts" class="page-section">
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['most_title'] ) ?></h2>
                </div><!-- .section-header -->

                <div class="section-content magazine col-2 clear">
                    <?php foreach ($content_details as $content): ?>
                        <article class="hentry">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ?></a></h2>
                                </header>

                                <div class="entry-meta">
                                    <?php pet_business_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach ?>

                </div><!-- .section-content -->
            </div>
        </div>               	

    <?php }
endif;