<?php
/**
 * Project section
 *
 * This is the template for the content of project section
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */
if ( ! function_exists( 'pet_business_pro_add_project_section' ) ) :
    /**
    * Add project section
    *
    *@since Pet Business Pro 1.0.0
    */
    function pet_business_pro_add_project_section() {
        $options = pet_business_pro_get_theme_options();
        // Check if project is enabled on frontpage
        $project_enable = apply_filters( 'pet_business_pro_section_status', true, 'project_section_enable' );

        if ( true !== $project_enable ) {
            return false;
        }
        // Get project section details
        $section_details = array();
        $section_details = apply_filters( 'pet_business_pro_filter_project_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render project section now.
        pet_business_pro_render_project_section( $section_details );
    }
endif;

if ( ! function_exists( 'pet_business_pro_get_project_section_details' ) ) :
    /**
    * project section details.
    *
    * @since Pet Business Pro 1.0.0
    * @param array $input project section details.
    */
    function pet_business_pro_get_project_section_details( $input ) {
        $options = pet_business_pro_get_theme_options();

        // Content type.
        $project_content_type  = $options['project_content_type'];
        $project_count = ! empty( $options['project_count'] ) ? $options['project_count'] : 6;
        
        $content = array();
        switch ( $project_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $project_count; $i++ ) {
                    if ( ! empty( $options['project_content_page_' . $i] ) )
                        $page_ids[] = $options['project_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $project_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $project_count; $i++ ) {
                    if ( ! empty( $options['project_content_post_' . $i] ) )
                        $post_ids[] = $options['project_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $project_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['project_content_category'] ) ? $options['project_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $project_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['content']     = pet_business_pro_trim_content( 15 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                $page_post['id'] = get_the_ID();
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// project section content details.
add_filter( 'pet_business_pro_filter_project_section_details', 'pet_business_pro_get_project_section_details' );


if ( ! function_exists( 'pet_business_pro_render_project_section' ) ) :
  /**
   * Start project section
   *
   * @return string project content
   * @since Pet Business Pro 1.0.0
   *
   */
   function pet_business_pro_render_project_section( $content_details = array() ) {
        $options = pet_business_pro_get_theme_options();
        $project_content_type  = $options['project_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' ): ?>

        <div id="latest-projects" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( ! empty( $options['project_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['project_title'] ); ?></h2>
                    <?php endif; ?>
                    <?php if ( ! empty( $options['project_sub_title'] ) ) : ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['project_sub_title'] ); ?></p>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="project-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "fade": false }'>
                    <?php 
                    $i = 1;
                    foreach ( $content_details as $content ) : 
                        ?>
                        <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="overlay"></div>
                            <div class="entry-container">
                                <div class="entry-container">
                                    <?php if ( ! empty( $content['title'] ) ) : ?>
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>
                                    <?php endif; ?>
                                    <div class="entry-meta">
                                        <span class="cat-links">
                                            <?php 
                                            if ( 'page' !== $project_content_type ) {
                                                $categories_list = get_the_category_list( esc_html__( ', ', 'pet-business-pro' ), '', $content['id'] );
                                                echo $categories_list; // WPCS: XSS OK.
                                            } else {
                                                if ( ! empty( $options['project_custom_meta_' . $i] ) ) {
                                                    echo esc_html( $options['project_custom_meta_' . $i] );
                                                }
                                            }
                                        ?>
                                        </span>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php 
                    $i++;
                    endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #project-experience -->

    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'second-design' ): ?>

        <div id="blog-featured-posts" class="relative page-section">
                <div class="wrapper">
                <?php if ( ! empty( $options['project_title'] ) ) : ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['project_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                    <div class="blog-section-content clear">
                        <?php $i = 1; foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="blog-featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    
                                </div><!-- .blog-featured-image -->
                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php 
                                        if ( 'page' !== $project_content_type ) {
                                            $categories_list = get_the_category_list( esc_html__( ', ', 'pet-business-pro' ), '', $content['id'] );
                                                echo $categories_list; // WPCS: XSS OK.
                                            } else {
                                                if ( ! empty( $options['project_custom_meta_' . $i] ) ) {
                                                    echo esc_html( $options['project_custom_meta_' . $i] );
                                                }
                                            }
                                            ?>                              
                                        </span><!-- .cat-links -->

                                        <?php if ( ! empty( $content['title'] ) ) : ?>
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                        <?php endif; ?>

                                        <?php pet_business_pro_posted_on($content['id']); ?>
                                    </div><!-- .entry-container -->
                                </article>
                            <?php $i++; endforeach; ?>
                    </div><!-- .blog-section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'fourth-design' ): ?>

        <div id="medical-services" class="relative page-section">
                <div class="wrapper">
                    <div class="section-content col-3 clear">

                    <?php foreach ( $content_details as $content ) :  ?>

                        <article>
                            <div class="medical-service-item">
                                <div class="inner-box">
                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>"></a>
                                    </div><!-- .featured-image -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header><!-- .entry-header -->
                                </div><!-- .inner-box -->
                            </div><!-- .medical-service-item -->
                        </article>

                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php endif; ?>
    <?php }
endif;