<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Pet Business Pro
 * @since Pet Business Pro 1.0.0
 */
if ( ! function_exists( 'pet_business_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Pet Business Pro 1.0.0
    */
    function pet_business_pro_add_slider_section() {
    	$options = pet_business_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'pet_business_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'pet_business_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        pet_business_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'pet_business_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Pet Business Pro 1.0.0
    * @param array $input slider section details.
    */
    function pet_business_pro_get_slider_section_details( $input ) {
        $options = pet_business_pro_get_theme_options();

        // Content type.
        $slider_content_type  = $options['slider_content_type'];
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 4;
        
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'custom':
                for ( $i=1; $i <= $options['slider_count']; $i++ ) { 
                    $custom['title']       = ! empty( $options['slider_content_custom_title_' . $i ] ) ? $options['slider_content_custom_title_' . $i ] : '';
                    $custom['url']        = ! empty( $options['slider_content_custom_url_' . $i ] ) ? $options['slider_content_custom_url_' . $i ] : '';
                    $custom['excerpt']        = ! empty( $options['slider_content_custom_content_' . $i ] ) ? $options['slider_content_custom_content_' . $i ] : '';
                    $custom['img']        = ! empty( $options['slider_content_custom_image_' . $i ] ) ? $options['slider_content_custom_image_' . $i ] : '';
                    array_push( $content, $custom );
                }

                // Push to the main array.
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        if ( 'custom' != $slider_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = pet_business_pro_trim_content( 30 );
                    $page_post['img']   = get_the_post_thumbnail_url( null, 'large' );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        }

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'pet_business_pro_filter_slider_section_details', 'pet_business_pro_get_slider_section_details' );


if ( ! function_exists( 'pet_business_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Pet Business Pro 1.0.0
   *
   */
   function pet_business_pro_render_slider_section( $content_details = array() ) {
        $options = pet_business_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design'): ?>

         <div id="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":true, "autoplay": true, "fade": true }'>
            <?php 
            $i = 1;
            foreach ( $content_details as $content ) : ?>
                <article style="background-image: url('<?php echo esc_url( $content['img'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="entry-container">
                        <header class="entry-header">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <h2 class="entry-title">
                                    <?php echo esc_html( $content['title'] ); ?>
                                </h2>
                            <?php endif; ?>
                        </header>

                        <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div>
                        <?php endif; ?>
                        <div class="buttons">
                            <?php if ( ! empty( $options['slider_content_custom_btn_1_' . $i ] ) ) : 
                                $btn_1_url = ! empty( $options['slider_content_custom_url_1_' . $i ] ) ? $options['slider_content_custom_url_1_' . $i ] : '';
                                ?>
                                <a href="<?php echo esc_url( $btn_1_url ); ?>" class="btn btn-default"><?php echo esc_html( $options['slider_content_custom_btn_1_' . $i ] ); ?></a>
                            <?php endif; ?>
                            <?php if ( ! empty( $options['slider_content_custom_btn_2_' . $i ] ) ) : 
                                $btn_2_url = ! empty( $options['slider_content_custom_url_2_' . $i ] ) ? $options['slider_content_custom_url_2_' . $i ] : '';

                                ?>
                                <a href="<?php echo esc_url( $btn_2_url ); ?>" class="btn btn-primary"><?php echo esc_html( $options['slider_content_custom_btn_2_' . $i ] ); ?></a>
                            <?php endif; ?>
                        </div><!-- .buttons -->
                    </div>
                </article>
            <?php 
            $i++;
            endforeach; ?>
        </div><!-- #featured-slider -->

    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'second-design' ): ?>

        <div id="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":true, "autoplay": true, "fade": true }'>

        <?php foreach ( $content_details as $content ) : ?>

                <article style="background-image: url('<?php echo esc_url( $content['img'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="entry-container">
                    <?php if ( ! empty( $content['title'] ) ) : ?>
                        <header class="entry-header">
                            <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                        </header>
                    <?php endif; ?>

                        <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                        <div class="entry-content">
                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content -->
                    <?php endif;

                    if ( ! empty( $options['slider_blog_button'] ) ): ?>
                        <div class="buttons">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-default"><?php echo esc_html( $options['slider_blog_button'] ); ?></a>
                        </div><!-- .buttons -->
                    <?php endif; ?>
                    </div><!-- .entry-container -->
                </article>

        <?php endforeach; ?>

            </div><!-- #featured-slider -->

    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'fourth-design' ): ?>

        <div id="medical-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": false, "draggable": true, "fade": false, "adaptiveHeight": true }'>
                
                <?php foreach ( $content_details as $content ) : ?>

                <article style="background-image:url('<?php echo esc_url( $content['img'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="medical-slider-wrapper">
                    <?php if ( ! empty( $content['title'] ) ) : ?>
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>
                    <?php endif; ?>

                        <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                        <div class="entry-content">
                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content-->
                    <?php endif; ?>

                        <?php if ( ! empty( $options['slider_blog_button'] ) ): ?>
                        <div class="medical-read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['slider_blog_button'] ); ?></a>
                        </div><!-- .medical-read-more -->
                    <?php endif; ?>
                    </div><!-- .medical-slider-wrapper -->
                </article>

                <?php endforeach; ?>

            </div>

    <?php endif; ?>
            
    <?php }
endif;